@@ -1,5 +1,7 @@
+import sys
+
 from _pytest import main as pytest_main
-from find_dependencies.dependency_finder import DependencyFinder
+from find_dependencies.dependency_finder import DependencyFinder, run_tests
 
 
 def pytest_addoption(parser):
@@ -10,9 +12,22 @@ def pytest_addoption(parser):
         dest="find_dependencies",
         help="""Find dependencies between tests""",
     )
+    group.addoption(
+        "--find-dependencies-internal",
+        action="store_true",
+        dest="find_dependencies_internal",
+        help="""For internal use only""",
+    )
+
+
+def pytest_cmdline_preparse(args):
+    if "--find-dependencies" in args and "pytest_randomly" in sys.modules:
+        args[:] = ["--randomly-dont-reorganize"] + args
 
 
 def pytest_runtestloop(session):
+    if session.config.getoption("find_dependencies_internal"):
+        return run_tests(session)
     if not session.config.getoption("find_dependencies"):
         return pytest_main.pytest_runtestloop(session)
 
